@@ -906,9 +906,9 @@ class BaseExperiment:
                 ckpt_extension_type = str(ckpt_dir).split('.')[-1]
                 if ckpt_extension_type not in extension_candidates:
                     raise ValueError(f"Wrong file extension {ckpt_extension_type} for the checkpoint. It should be in {extension_candidates}")
-                if ckpt_extension_type == ".sav":
+                if ckpt_extension_type == "sav":
                     best_ckpt = pickle.load(open(ckpt_dir, 'rb'))
-                elif BaseNet in inspect.getmro(model_type) or ConvNet in inspect.getmro(model_type):
+                elif BaseNet in inspect.getmro(eval(model_type)) or ConvNet in inspect.getmro(eval(model_type)):
                     best_ckpt = eval(model_type).load_from_checkpoint(dims=self.dims, n_classes=self.n_classes, checkpoint_path=ckpt_dir)
                 elif pl.LightningModule in inspect.getmro(model_type):
                     best_ckpt = eval(model_type).load_from_checkpoint(checkpoint_path=ckpt_dir)
